### Name: featureSignif
### Title: Feature significance for kernel density estimation
### Aliases: featureSignif
### Keywords: smooth

### ** Examples

## Univariate example
data(earthquake)
eq3 <- -log10(-earthquake[,3])

featureSignif(eq3, addSignifGradRegion=TRUE,xlab="-log(-depth)", bw=0.1)
featureSignif(eq3, plotSiZer=TRUE, xlab="-log(-depth)")
featureSignif(eq3, plotSiZer=TRUE, xlab="-log(-depth)", bwSiZer=c(0.05, 1.3),
  gridsizeSiZer=c(401, 101))

## Bivariate example

library(MASS)
data(geyser)

fs <- featureSignif(geyser, addSignifCurvRegion=TRUE, bw=c(4.5, 0.37),
      plotFS=FALSE)
plot(fs, addSignifCurvRegion=TRUE)

## Trivariate example

data(earthquake)
earthquake[,3] <- -log10(-earthquake[,3])

featureSignif(earthquake, scaleData=TRUE, addData=TRUE,
    bw=c(0.0618, 0.0602, 0.0558))
featureSignif(earthquake, addKDE=FALSE, scaleData=TRUE,
   addSignifCurvRegion=TRUE, bw=c(0.0618, 0.0602, 0.0558),  
   xlim=c(0.4,0.5), ylim=c(0.4,0.5), zlim=c(0.8,0.9))

## Not run: 
##D ## Interactive examples
##D 
##D library(MASS)
##D data(geyser)
##D duration <- geyser$duration 
##D 
##D ## Univariate example
##D 
##D featureSignif(duration)
##D featureSignif(duration, addData=TRUE)
##D featureSignif(duration, addSignifGradRegion=TRUE, addSignifGradData=TRUE)
##D featureSignif(duration, addSignifCurvRegion=TRUE, addSignifCurvData=TRUE)
##D 
##D ## Bivariate example
##D 
##D featureSignif(geyser, addData=TRUE, addSignifCurvRegion=TRUE)
##D featureSignif(geyser, addData=TRUE, addSignifCurvRegion=TRUE,
##D    bw=rbind(c(1, 0.1), c(5, 0.9)))
##D    ## bandwidths ranges: h1 in c(1, 5), h2 in c(0.1, 0.9)
##D 
##D ## Trivariate example
##D 
##D data(earthquake)
##D earthquake$depth <- -log10(-earthquake$depth)
##D featureSignif(earthquake, addSignifCurvRegion=TRUE, scaleData=TRUE)
##D 
## End(Not run)



